@@ -6,9 +6,10 @@ import babelfish
 class Context(dict):
     def __init__(self, options: typing.Optional[typing.Mapping[str, typing.Any]] = None):
         super().__init__(options or {})
-        self.expected_language: typing.Optional[babelfish.Language] = (
-            babelfish.Language.fromietf(self['expected_language']) if 'expected_language' in self else None
-        )
+        language = self['expected_language'] if 'expected_language' in self else None
+        if language and not isinstance(language, babelfish.Language):
+            language = babelfish.Language.fromietf(str(language))
+        self.expected_language: typing.Optional[babelfish.Language] = language
 
     def accept(self, lang: babelfish.Language):
         if self.expected_language is None:
